@@ -1043,8 +1043,14 @@ class Access(object):
                         # Something really bad happened.
                         body = json.loads(response.text)
                         if body.get('err'):
+
+                            logging.error("*" * 50)
+                            logging.error(response.headers)
                             logging.error(body)
+                            logging.error("*" * 50)
+
                             message = body.get('message')
+
                             if message is not None and "field" in body["message"][0]:
                                 # User error, easy
                                 raise DatacoreException(
@@ -1203,8 +1209,14 @@ class Access(object):
                         # Something really bad happened.
                         body = json.loads(response.text)
                         if body.get('err'):
+
+                            logging.error("*" * 50)
+                            logging.error(response.headers)
                             logging.error(body)
+                            logging.error("*" * 50)
+
                             message = body.get('message')
+
                             if message is not None and "field" in body["message"][0]:
                                 # User error, easy
                                 raise DatacoreException(
